@@ -91,7 +91,7 @@ def stomp_connection():
             raise RuntimeError('stomp was configured to publish messages,, '
                                'but connection is not configured in STOMP_CONFIGS')
         conn = stomp.Connection(**configs['connection'])
-        conn.connect(**configs.get('credentials', {}))
+        conn.connect(wait=True, **configs.get('credentials', {}))
         try:
             yield conn
         finally:
